
/* This file is part of the Corteo project
   Copyright (C) 2004-2015 Francois Schiettekatte <francois.schiettekatte@umontreal.ca>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef CORTEOPARAMWIDGET_H
#define CORTEOPARAMWIDGET_H

#include <QMainWindow>
#include <QtXml>
#include <QTextEdit>
#include <QPushButton>
#include <QSlider>
#include <QString>
#include <QSplashScreen>

#include "ui_CorteoParamWidget.h"

#include "../corteo/techniques.h"

#include "LayerForm.h"
#include "DetectorForm.h"
#include "CalibrationForm.h"

#include "XYQt/PeriodicTable.h"

#define TECH_FULLBACK  -99   // RBS background: call full RBS simulation but only load detected ions below cut-off angle

class pixelArea;

class CorteoParamWidget : public QWidget, public Ui::CorteoParamWidget 
{

  Q_OBJECT
  
private:

  pixelArea * labelPixels;

  QList<int>  techniqueCode;
  QStringList techniqueName;

  LayerForm * foil;
  QDialog   * foilDialog; 

  // detector tab forms
  QList<DetectorForm *> detector;

  // calibration tab forms
  QList<CalibrationForm *> calibration;

  Atom  beamElement;

  QString paramfile;

  QIcon gray, green;

  void setUseLayerIcon(int ilayer);
  void setUseDetectorIcon(int idet);
  
  bool swapLayers(int layer1, int layer2);
  void setLayerTitle(int ilayer);
  void updateLayer(int ilayer);
  void setLoadedMaterialColors();

  // layer parameter tab forms
  QList<LayerForm *> layer;

  QString pixelFilename;
  QList<QImage> pixels;
  QSet<QRgb> pixelsColorUsed;
  bool loadPixels(QString filename);
  bool writeCorteoBitmap(int *xDim, int *yDim, int *zDim, int *substrateLayer);

  QColor beamColor;
  QColor deteColor;

private slots:
  void setBeam();

  void update();
  void updateUsePixels();
  void useLayerChanged();

  bool moveLayerToPrevious();
  bool moveLayerToNext();
  void moveLayerEnable(int ilayer);

  void loadFile();
  void saveFile();
  bool saveParam();
  void saveFileAs();

  void loadPixels();
  void genPixels();
  void drawPixels(int z = -1);

  void showCorteoLog();

public:
	CorteoParamWidget(QWidget * parent, int maxlayer, int maxelement, QSplashScreen * splash = 0);
  
  int  technique();
  int  stragglingType();
  int  screening();
  int  nthread();
  void setStragglingType(int type);

  bool saveParam(QString filename);
  bool loadParam(QString filename);

  QString corteo(bool *error, int technique);

  QDomElement XMLNode(QDomDocument &doc);
  void setFromNode( QDomNode n);

  bool isUsedLayer(int ilayer);
  bool isUsedElement(int ilayer, int ielement);
  bool isSimulatedElement(int ilayer, int ielement);
  int  numberIsotopesToSimulate(int ilayer, int ielement);
  double fraction(int ilayer, int ielement);

  int  numberLayer();
  int  numberElement(int ilayer);
  int  numberSimul();
  CalibrationForm * getCalibrationForm(int Z) { return calibration[Z]; }

  Atom element(int ilayer, int ielement);
  double elementMass(int ilayer, int ielement);

  Atom beam() {return beamElement;}
  double beamMass();
  QString listFile;

public slots:

  void editFoil();
  bool isBeamDetectionTechnique();
  bool isTOF();

  void aboutCorteoUi();

};

#endif // CORTEOPARAMWIDGET_H

