/* This file is part of the Corteo project
   Copyright (C) 2004-2015 Francois Schiettekatte <francois.schiettekatte@umontreal.ca>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef CORTEOUI_H
#define CORTEOUI_H

#include <QtXml>
#include <QtGui>
#include <QProgressDialog>

#include "CorteoParamWidget.h"
#include "LayerForm.h"
#include "DetectorForm.h"
#include "CalibrationForm.h"

#include "XYQt/FSGraph.h"
#include "XYQt/PeriodicTable.h"

class CorteoUi : public QMainWindow
{
  Q_OBJECT

private:

  //bool isError;

  CorteoParamWidget * paramUi; // parameter toolbox 
  QProgressDialog   * progress; // progress bar during simulations

  QTabWidget * tab; // tab containing graphs and constituing main window

  FSGraph * mainGraph;
  FSGraph * angleGraph;

  QProcess * corteoProcess;

  QString corteoOutput, corteoError;

public:
  CorteoUi(QWidget *parent = 0, int maxlayer = 5, int maxelement = 5, QSplashScreen * splash = 0);

  bool writeCorteoIn(int technique);
  bool readIBAOutput();

  bool runCorteo(int technique);
  bool printLog();

  void addAngleData(FSDataSet * angleData);

public slots:

  bool go();
  bool applyCalib();

  void updateProgress();
  void readImplOutput(int exitStatus);
  void readIBAOutput(int exitStatus);
  void readFullRBS(int exitStatus);
  void readEnerDepthOut(int exitStatus);

  void UpdateConnectCorteoLoadPushbutton();

  bool writeCorteoIn();
  bool readCorteoDetect();
  bool readCorteoDetectFullRBS();
  bool readCorteoOut();
  void readEnerDepthMap();
  void readEnerDepthList();

  void endSimulations();

};

#endif // CORTEOUI_H



