/* This file is part of the Corteo project
   Copyright (C) 2004-2015 Francois Schiettekatte <francois.schiettekatte@umontreal.ca>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef ELEMENTFORM_H
#define ELEMENTFORM_H

#include<QtXml>

#include "ui_ElementForm.h"
#include "XYQt/PeriodicTable.h"
#include "XYQt/FSDoubleValidator.h"

class ElementForm : public QWidget, public Ui::ElementForm
{
  Q_OBJECT

private:
  Atom _element;

public slots:
  Atom setElement();

public:

  ElementForm(QWidget * parent);
  virtual ~ElementForm() {};

  bool setFromNode(QDomNode &n);
  QDomElement XMLNode(QDomDocument &doc);

  static Atom selectElement(QWidget * parent);
  static Atom selectElement(QWidget * parent, QPushButton * pb, QComboBox * cb);

  static Atom setElement(QString atomicSymbol, QPushButton* pb, QComboBox *cb, double mass = 0);
  static Atom setElement(Atom a, QPushButton * pb, QComboBox * cb, double mass = 0);
  static Atom setElement(int  Z, QPushButton * pb, QComboBox * cb, double mass = 0);

  Atom setElement(QString atomicSymbol, double mass = 0);
  Atom setElement(int Z, double mass = 0);
  void setElement(Atom a, double mass = 0);

  QString ZMass(int isotope = -1);
  double mass();
  double concentration();
  double compoundCorr();
  QString corteo();
  Atom element() { return _element; }


  bool update(bool isDetection, bool isFullCascade);

  bool isUsed();
  int numberIsotopesToSimulate();

};

#endif // ELEMENTFORM_H
