/* This file is part of the Corteo project
   Copyright (C) 2004-2015 Francois Schiettekatte <francois.schiettekatte@umontreal.ca>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

// Dialog for editing datasets plotting properties

#include <QPen>
#include <QPixmap>
#include <QValidator>
#include <QColorDialog>

#include "FSEditDataSet.h"
#include "xpmSymbol.h"
#include "xpmLineStyle.h"

FSEditDataSet::FSEditDataSet(FSDataSet * d, QWidget *parent)
            : QDialog( parent )
{
    QIntValidator    * validatorInt    = new QIntValidator(2,99, this);
    QDoubleValidator * validatorDouble = new QDoubleValidator(0,99,3, this);

    setupUi(this);
    pm = QPixmap(20,20);

    selectedLineColor   = d->linePen.color();
    selectedSymbolColor = d->symbolPen.color();
  
    legendEdit->setText(d->legend);

    // line
    lineWidthEdit->setText(QString::number(d->linePen.width()));
    lineWidthEdit->setValidator(validatorInt);

    lineStyleBox->addItem(QIcon(QPixmap(lsNone_xpm)),"none");
    lineStyleBox->addItem(QIcon(QPixmap(lsSolid_xpm)),"solid");
    lineStyleBox->addItem(QIcon(QPixmap(lsDash_xpm)),"dot");
    lineStyleBox->addItem(QIcon(QPixmap(lsDot_xpm)),"dot");
    lineStyleBox->addItem(QIcon(QPixmap(lsDashDot_xpm)),"dash-dot");
    lineStyleBox->addItem(QIcon(QPixmap(lsDashDotDot_xpm)),"dash-dot-dot");
    lineStyleBox->setCurrentIndex(d->linePen.style());

    pm.fill(selectedLineColor);
    lineColorbt->setIcon(QIcon(pm));
    connect( lineColorbt, SIGNAL(clicked()), SLOT(newLineColor()) );

    // symbol
    symbolBox->addItem(QIcon(QPixmap(symNone_xpm)),"" );
    symbolBox->addItem(QIcon(QPixmap(symECircle_xpm)),"" );
    symbolBox->addItem(QIcon(QPixmap(symFCircle_xpm)),"" );
    symbolBox->addItem(QIcon(QPixmap(symESquare_xpm)),"" );
    symbolBox->addItem(QIcon(QPixmap(symFSquare_xpm)),"" );
    symbolBox->addItem(QIcon(QPixmap(symETriangle_xpm)),"" );
    symbolBox->addItem(QIcon(QPixmap(symFTriangle_xpm)),"" );
    symbolBox->addItem(QIcon(QPixmap(symERevTriangle_xpm)),"" );
    symbolBox->addItem(QIcon(QPixmap(symFRevTriangle_xpm)),"" );
    symbolBox->addItem(QIcon(QPixmap(symPlus_xpm)),"" );
    symbolBox->addItem(QIcon(QPixmap(symStar_xpm)),"" );
    symbolBox->addItem(QIcon(QPixmap(symDot_xpm)),"" );
    symbolBox->addItem(QIcon(QPixmap(sym2DHist_xpm)),"" );
    symbolBox->setCurrentIndex(d->getsymbol());

    symbolSizeEdit->setText(QString::number(d->getsymbolSize()));
    symbolSizeEdit->setValidator(validatorDouble);

    pm.fill(selectedSymbolColor);
    symbolColorbt->setIcon(QIcon(pm));
    connect( symbolColorbt, SIGNAL(clicked()), SLOT(newSymbolColor()) );

}

QString FSEditDataSet::legend( void )
{
    return legendEdit->text();
}

QPen FSEditDataSet::linePen( void )
{
    return QPen(QBrush(selectedLineColor),lineWidthEdit->text().toInt(),Qt::PenStyle(lineStyleBox->currentIndex()));
}

QPen FSEditDataSet::symbolPen( void )
{
    return QPen(QBrush(selectedSymbolColor),1,Qt::SolidLine);
}

int FSEditDataSet::symbol( void )
{
    return symbolBox->currentIndex();
}

double FSEditDataSet::symbolSize( void )
{
    return symbolSizeEdit->text().toDouble();
}

void FSEditDataSet::newLineColor( void )
{
    QColor c = QColorDialog::getColor(selectedLineColor, this);
    if(c.isValid())
    {
        selectedLineColor = c;
        pm.fill(selectedLineColor);
        lineColorbt->setIcon(QIcon(pm));
    }
}

void FSEditDataSet::newSymbolColor( void )
{
    QColor c = QColorDialog::getColor(selectedSymbolColor, this);
    if(c.isValid())
    {
        selectedSymbolColor = c;
        pm.fill(selectedSymbolColor);
        symbolColorbt->setIcon(QIcon(pm));
    }
}
