/* This file is part of the Corteo project
   Copyright (C) 2004-2015 Francois Schiettekatte <francois.schiettekatte@umontreal.ca>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

// Dialog for editing legend properties
#include <QPen>
#include <QFontDialog>
#include <QColorDialog>

#include "FSEditLegend.h"
#include "xpmLineStyle.h"

FSEditLegend::FSEditLegend(QPen legPen, QFont legFont, int legPos, QWidget *parent )
            : QDialog( parent)
{
    QIntValidator    * validatorInt    = new QIntValidator(2,99, this);

    setupUi(this);
    pm = QPixmap(20,20);

    selectedFont  = legFont;
    selectedColor = legPen.color();

    switch (legPos) {
    case 0:
      legNone->setChecked( true );
      break;
    case 1:
      legLeft->setChecked( true );
      break;
    case 2:
      legRight->setChecked( true );
      break;
    case 3:
    default:
      legOutside->setChecked( true );
      break;
    }
    // frame line
    lineWidthEdit->setText(QString::number(legPen.width()));
    lineWidthEdit->setValidator(validatorInt);

    lineStyleBox->addItem(QIcon(QPixmap(lsNone_xpm)),"none");
    lineStyleBox->addItem(QIcon(QPixmap(lsSolid_xpm)),"solid");
    lineStyleBox->addItem(QIcon(QPixmap(lsDash_xpm)),"dot");
    lineStyleBox->addItem(QIcon(QPixmap(lsDot_xpm)),"dot");
    lineStyleBox->addItem(QIcon(QPixmap(lsDashDot_xpm)),"dash-dot");
    lineStyleBox->addItem(QIcon(QPixmap(lsDashDotDot_xpm)),"dash-dot-dot");
    lineStyleBox->setCurrentIndex(legPen.style());

    pm.fill(selectedColor);
    colorbt->setIcon(QIcon(pm));
    connect( colorbt, SIGNAL(clicked()), SLOT(newColor()) );

    connect( fontbt, SIGNAL(clicked()), SLOT(newFont()) );

}

void FSEditLegend::newFont()
{
    bool ok;
    QFont f = QFontDialog::getFont(&ok, selectedFont, this);
    if(ok) selectedFont = f;
}

void FSEditLegend::newColor( void )
{
    QColor c = QColorDialog::getColor(selectedColor, this);
    if(c.isValid()) {
        selectedColor = c;
        pm.fill(selectedColor);
        colorbt->setIcon(QIcon(pm));
    }
}


QPen FSEditLegend::pen( void )
{
    return QPen(QBrush(selectedColor),lineWidthEdit->text().toInt(),Qt::PenStyle(lineStyleBox->currentIndex()));
}

int FSEditLegend::pos( void )
{
    if(legNone->isChecked()) return 0;
    else if(legLeft->isChecked()) return 1;
    else if(legRight->isChecked()) return 2;
    else return 3;
}
