/* This file is part of the Corteo project
   Copyright (C) 2004-2015 Francois Schiettekatte <francois.schiettekatte@umontreal.ca>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef PERIODICTABLE_H
#define PERIODICTABLE_H


#include <QDialog>
#include <QPushButton>
#include <QList> 

class Atom 
{
public:
  QString       symbol;
  int           Z;
  int           MAI;             // index of Most Abundant Isotope in isotopeMass list
  double        averageMass;
  QList<QString> isotopeMass;    // mass as string to retain digits
  QList<double>  isotopeAbundance;
  bool operator ==(const Atom& other) const{return &other == this;}

  Atom(); 
  int  nIsotopes();
  void findMAI();
  void computeAverageMass();
};


class PeriodicTable : public QWidget {

	Q_OBJECT

private:
	void setSelected(int Z, bool sel = true);
	void paintEvent( QPaintEvent * );

  QList<int> multiSelected();

  void createTableOfElements(int width, int height);
  bool loadAtoms();

  QList<Atom> atoms;      // Atom list
  QList<QPushButton *> cb;  // buttons representing elements

  Atom _selectedElement;

  int lastClicked;
	QList<int> ZSelected;

public:
	PeriodicTable(int w = 300, int h = 200, bool singleSelect = true, QWidget *parent=0);
	Atom returnAtom(int atomNum);
	Atom returnAtom(QString atomSymbol);
  Atom selectedElement() { return _selectedElement; }
  int  countAtoms() {return atoms.count(); }

public slots:
	void singleElementSelect();
	void multiElementSelect();

signals:
	void elementSelected();

};

#endif //PERIODICTABLE_H

